# Logto Python SDK

[![Logto](https://img.shields.io/badge/for-logto-7958ff)][Website]
[![Stable Version](https://img.shields.io/pypi/v/logto?label=stable)][PyPI Releases]
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/logto)][PyPI]
[![PyPI - License](https://img.shields.io/pypi/l/logto)](https://github.com/logto-io/python)
[![Discord](https://img.shields.io/discord/965845662535147551?color=5865f2&logo=discord&label=discord)][Discord]

## Prerequisites

- Python 3.8 or higher
- A [Logto Cloud][Website] account or a self-hosted Logto
- A Logto traditional web application created

If you don't have the Logto application created, please follow the [⚡ Get started](https://docs.logto.io/docs/tutorials/get-started/) guide to create one.

## Installation
```bash
pip install logto # or `poetry add logto` or whatever you use
```

## Tutorial

See [tutorial](./docs/tutorial.md) for a quick start.

## API reference

See [API reference](./docs/api.md) for more details.

## Sample code

See [samples](./samples/) directory for example usages.

## Resources

- [Logto website][Website]
- [Logto documentation](https://docs.logto.io/)
- [Join Discord][Discord]

[Website]: https://logto.io/
[PyPI]: https://pypi.org/project/logto/
[PyPI Releases]: https://pypi.org/project/logto/#history
[Discord]: https://discord.gg/vRvwuwgpVX
